@@ -3,6 +3,7 @@ knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
 )
+set.seed(0)
 
 ## ----echo=FALSE, out.width="50%", fig.cap = "Simulation study of a model"-----
 knitr::include_graphics("vig07_fig.png")
@@ -14,25 +15,30 @@ library(poputils)
 
 divorces_small <- nzl_divorces |>
   filter(age_upper(age) < 40,
-         time >= 2016) |>
+         time >= 2018) |>
   droplevels()
 
-mod <- mod_pois(divorces ~ age * sex + time,
+## -----------------------------------------------------------------------------
+mod <- mod_pois(divorces ~ age + sex + time,
                 data = divorces_small,
-		            exposure = population)
+		            exposure = population) |>
+  set_prior(`(Intercept)` ~ Known(-1)) |>
+  set_prior(age ~ RW(sd = 0.05, s = 0.05)) |>
+  set_prior(time ~ AR1(s = 0.05))
 mod		
 
-## -----------------------------------------------------------------------------
+## ----message = FALSE----------------------------------------------------------
 set.seed(0)
 res <- report_sim(mod_est = mod)
 res
 
 ## -----------------------------------------------------------------------------
-mod_ar1 <- mod |>
-  set_prior(time ~ AR1())
-mod_ar1	
+mod_rw <- mod |>
+  set_prior(time ~ RW(s = 0.05))
+mod_rw	
 
-## -----------------------------------------------------------------------------
-res_ar1 <- report_sim(mod_est = mod, mod_sim = mod_ar1)
-res_ar1
+## ----message = FALSE----------------------------------------------------------
+set.seed(0)
+res_rw <- report_sim(mod_est = mod, mod_sim = mod_rw)
+res_rw
 
