@@ -213,6 +213,163 @@ test_that("'check_covariates_formula' throws the correct error when 'formula' in
 })
 
 
+
+## 'check_datamod_by_val' -----------------------------------------------------
+
+test_that("'check_datamod_by_val' returns TRUE with valid inputs", {
+  set.seed(0)
+  by_val <- expand.grid(age = 0:2, sex = c("f", "m"))
+  data <- expand.grid(reg = 1:2, age = 0:1, sex = c("f", "m"))
+  expect_true(check_datamod_by_val(by_val = by_val,
+                                   data = data,
+                                   nm_val = "prob",
+                                   nm_data = "data"))
+})
+
+test_that("'check_datamod_by_val' throws correct error when by_val has extra variable", {
+  set.seed(0)
+  by_val <- expand.grid(age = 0:2, sex = c("f", "m"), wrong = 1:2)
+  data <- expand.grid(reg = 1:2, age = 0:1, sex = c("f", "m"))
+  expect_error(check_datamod_by_val(by_val = by_val,
+                                    data = data,
+                                    nm_val = "prob",
+                                    nm_data = "df"),
+               "Variable `wrong` from `prob` not found in `df`.")
+})
+
+test_that("'check_datamod_by_val' throws correct error when by_val missing combination of by variables", {
+  set.seed(0)
+  by_val <- expand.grid(age = 0:2, sex = c("f", "m"))
+  data <- expand.grid(reg = 1:2, age = 0:3, sex = c("f", "m"))
+  expect_error(check_datamod_by_val(by_val = by_val,
+                                    data = data,
+                                    nm_val = "prob",
+                                    nm_data = "df"),
+               "`prob` does not include all combinations of 'by' variables.")
+})
+
+test_that("'check_datamod_by_val' throws correct error when by_val missing single by variables", {
+  set.seed(0)
+  by_val <- expand.grid(age = 0:2)
+  data <- expand.grid(reg = 1:2, age = 0:3, sex = c("f", "m"))
+  expect_error(check_datamod_by_val(by_val = by_val,
+                                    data = data,
+                                    nm_val = "prob",
+                                    nm_data = "df"),
+               "`prob` does not include all levels of 'by' variable.")
+})
+
+
+## 'check_datamod_val' --------------------------------------------------------
+
+test_that("'check_datamod_val' returns TRUE with valid inputs", {
+  set.seed(0)
+  x <- expand.grid(age = 0:2, sex = c("f", "m"))
+  x$mean <- runif(6)
+  x$disp <- runif(6)
+  expect_true(check_datamod_val(x = x,
+                                nm_x = "prob",
+                                measure_vars = c("mean", "disp")))
+})
+
+test_that("'check_datamod_val' raises correct error wtih duplicated variables", {
+  set.seed(0)
+  x <- expand.grid(age = 0:2, sex = c("f", "m"))
+  x$mean <- runif(6)
+  x$disp <- runif(6)
+  names(x)[2] <- "age"
+  expect_error(check_datamod_val(x = x,
+                                 nm_x = "prob",
+                                 measure_vars = c("mean", "disp")),
+               "`prob` has more than one variable called \"age\".")
+})
+
+test_that("'check_datamod_val' raises correct error missing measure var", {
+  set.seed(0)
+  x <- expand.grid(age = 0:2, sex = c("f", "m"))
+  x$mean <- runif(6)
+  expect_error(check_datamod_val(x = x,
+                                 nm_x = "prob",
+                                 measure_vars = c("mean", "disp")),
+               "`prob` does not have a variable called \"disp\".")
+})
+
+test_that("'check_datamod_val' raises correct error with non-numeric measure var", {
+  set.seed(0)
+  x <- expand.grid(age = 0:2, sex = c("f", "m"))
+  x$mean <- runif(6)
+  x$disp <- "a"
+  expect_error(check_datamod_val(x = x,
+                                 nm_x = "prob",
+                                 measure_vars = c("mean", "disp")),
+               "Variable `disp` in `prob` is non-numeric.")
+})
+
+test_that("'check_datamod_val' raises correct error with NA in measure var", {
+  set.seed(0)
+  x <- expand.grid(age = 0:2, sex = c("f", "m"))
+  x$mean <- runif(6)
+  x$disp <- c(runif(5), NA)
+  expect_error(check_datamod_val(x = x,
+                                 nm_x = "prob",
+                                 measure_vars = c("mean", "disp")),
+               "Variable `disp` in `prob` has NA.")
+  x$disp <- c(NA, runif(4), NA)
+  expect_error(check_datamod_val(x = x,
+                                 nm_x = "prob",
+                                 measure_vars = c("mean", "disp")),
+               "Variable `disp` in `prob` has NAs.")
+})
+
+test_that("'check_datamod_val' raises correct error with Inf in measure var", {
+  set.seed(0)
+  x <- expand.grid(age = 0:2, sex = c("f", "m"))
+  x$mean <- runif(6)
+  x$disp <- c(runif(5), Inf)
+  expect_error(check_datamod_val(x = x,
+                                 nm_x = "prob",
+                                 measure_vars = c("mean", "disp")),
+               "Variable `disp` in `prob` has non-finite value.")
+  x$disp <- c(-Inf, runif(4), Inf)
+  expect_error(check_datamod_val(x = x,
+                                 nm_x = "prob",
+                                 measure_vars = c("mean", "disp")),
+               "Variable `disp` in `prob` has non-finite values.")
+})
+
+test_that("'check_datamod_val' raises correct error with no by variables", {
+  set.seed(0)
+  x <- data.frame(mean = runif(6), disp = runif(6))
+  expect_error(check_datamod_val(x = x,
+                                 nm_x = "prob",
+                                 measure_vars = c("mean", "disp")),
+               "`prob` has more than one row, but does not have any 'by' variables.")
+})
+
+test_that("'check_datamod_val' raises correct error with duplicated by variables - two variables", {
+  set.seed(0)
+  x <- expand.grid(age = 0:2, sex = c("f", "m"))
+  x <- rbind(x, data.frame(age = 0, sex = "f"))
+  x$mean <- runif(7)
+  x$disp <- runif(7)
+  expect_error(check_datamod_val(x = x,
+                                 nm_x = "prob",
+                                 measure_vars = c("mean", "disp")),
+               "`prob` has duplicated combinations of 'by' variables.")
+})
+
+test_that("'check_datamod_val' raises correct error with duplicated by variables - one variable", {
+  set.seed(0)
+  x <- data.frame(age = c(0:2, 0))
+  x$mean <- runif(4)
+  x$disp <- runif(4)
+  expect_error(check_datamod_val(x = x,
+                                 nm_x = "prob",
+                                 measure_vars = c("mean", "disp")),
+               "`prob` has duplicated levels for 'by' variable.")
+})
+
+
 ## 'check_est' ----------------------------------------------------------------
 
 test_that("'check_est' returns TRUE with valid inputs", {
@@ -482,7 +639,7 @@ test_that("'check_is_ssvd' works with valid inputs", {
 })
 
 
-## 'check_length_effect_ge' ------------------------------------------------------
+## 'check_length_effect_ge' ---------------------------------------------------
 
 test_that("'check_length_effect_ge' returns TRUE with valid inputs", {
     expect_true(check_length_effect_ge(length_effect = 10L,
@@ -500,6 +657,20 @@ test_that("'check_length_effect_ge' throws correct error with length less than m
 })
 
 
+## 'check_lt_one' -------------------------------------------------------------
+
+test_that("'check_lt_one' returns TRUE with valid inputs", {
+  expect_true(check_lt_one(c(0.9, -30, 0.5, NA, -Inf), nm_x = "x"))
+})
+
+test_that("'check_lt_one' throws correct error with valid inputs", {
+  expect_error(check_lt_one(c(1, -0.000001, 0.3, NA, -Inf), nm_x = "x", nm_df = "d"),
+               "Variable `x` in `d` has value greater than or equal to 1.")
+  expect_error(check_lt_one(c(1, -0.000001, 3, NA, Inf), nm_x = "x", nm_df = "d"),
+               "Variable `x` in `d` has values greater than or equal to 1.")
+})
+
+
 ## 'check_mod_est_sim_compatible' ---------------------------------------------
 
 test_that("'check_mod_est_sim_compatible' returns TRUE with indentical models", {
@@ -642,7 +813,7 @@ test_that("'check_mod_has_obs' returns correct error with no valid rows - no exp
 })
 
 
-## 'check_min_max_ar' --------------------------------------------------------------
+## 'check_min_max_ar' ---------------------------------------------------------
 
 test_that("'check_min_max_ar' returns TRUE with valid inputs", {
     expect_true(check_min_max_ar(min = -1, max = 1))
@@ -863,6 +1034,16 @@ test_that("'check_numeric' throws correct error with Inf", {
 })
 
 
+## 'check_offset_formula_not_used' --------------------------------------------
+
+test_that("'check_offset_formula_not_used' returns TRUE with valid offset", {
+  expect_true(check_offset_formula_not_used(nm_offset_data = "popn"))
+  rlang::local_options(lifecycle_verbosity = "warning")
+  expect_warning(check_offset_formula_not_used(nm_offset_data = "~popn + deaths"),
+                 "Using a formula to specify")
+})
+
+
 ## 'check_offset_in_data' -----------------------------------------------------
 
 test_that("'check_offset_in_data' returns TRUE with valid formula", {
@@ -1044,6 +1225,20 @@ test_that("'check_original_scale' raises warning when 'original_scale' ignored",
 })
               
 
+## 'check_positive' -----------------------------------------------------------
+
+test_that("'check_positive' returns TRUE with valid inputs", {
+  expect_true(check_positive(c(1, 0.000001, 3, NA, Inf), nm_x = "x", nm_df = "d"))
+})
+
+test_that("'check_positive' throws correct error with valid inputs", {
+  expect_error(check_positive(c(1, -0.000001, 3, NA, Inf), nm_x = "x", nm_df = "d"),
+               "Variable `x` in `d` has value less than or equal to 0.")
+  expect_error(check_positive(c(1, -0.000001, -3, NA, Inf), nm_x = "x", nm_df = "d"),
+               "Variable `x` in `d` has values less than or equal to 0.")
+})
+
+
 ## 'check_resp_le_offset' -----------------------------------------------------
 
 test_that("'check_resp_le_offset' returns TRUE with valid inputs - formula", {
@@ -1154,6 +1349,18 @@ test_that("'check_response_nonneg' returns correct error with invalid inputs", {
 })
 
 
+## 'check_response_not_call' --------------------------------------------------
+
+test_that("'check_response_not_call' returns TRUE with valid inputs", {
+    expect_true(check_response_not_call(deaths ~ sex))
+})
+
+test_that("'check_response_not_call' returns correct error with invalid inputs", {
+  expect_error(check_response_not_call(log(deaths) ~ sex),
+               "Response includes function call.")
+})
+
+
 ## 'check_scale' --------------------------------------------------------------
 
 test_that("'check_scale' returns TRUE with valid inputs", {
